SystemOrganization addCategory: #'ProcessWrapper-Core-Tests'!
SystemOrganization addCategory: #'ProcessWrapper-Core'!

Object subclass: #PWOutputStream
	instanceVariableNames: 'processWrapper readerSelector semaphoreSetterSelector semaphore dataStream atEnd binary'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ProcessWrapper-Core'!

!PWOutputStream class methodsFor: 'as yet unclassified' stamp: 'ul 7/19/2007 23:43'!
new

	self error: 'Instances of ', self name, ' should be created with #on:with:with:'! !

!PWOutputStream class methodsFor: 'as yet unclassified' stamp: 'ul 7/19/2007 23:52'!
on: aProcessWrapper with: readerSelector with: semaphoreSetterSelector

	^self basicNew
		processWrapper: aProcessWrapper;
		readerSelector: readerSelector;
		semaphoreSetterSelector: semaphoreSetterSelector;
		initialize;
		yourself! !

!PWOutputStream methodsFor: 'private - finalization' stamp: 'ul 7/21/2007 00:24'!
actAsExecutor

	super actAsExecutor.
	processWrapper := nil. "drop the reference so it can be garbage collected"
	


	
	
	! !

!PWOutputStream methodsFor: 'public' stamp: 'ul 7/19/2007 23:24'!
ascii

	binary := false! !

!PWOutputStream methodsFor: 'public' stamp: 'ul 7/20/2007 09:30'!
atEnd

	atEnd ifFalse: [
		dataStream atEnd ifTrue: [ self fetchDataBlock ] ].
	^atEnd
	! !

!PWOutputStream methodsFor: 'public' stamp: 'ul 7/19/2007 23:23'!
binary

	binary := true! !

!PWOutputStream methodsFor: 'private' stamp: 'ul 7/21/2007 00:31'!
fetchDataBlock

	| buffer bytesRead |
	buffer := self newBuffer: 4096.
	[ semaphore wait.
 	bytesRead := processWrapper perform: readerSelector with: buffer.
	bytesRead isZero ] whileTrue.
	bytesRead > buffer size ifTrue: [
		atEnd := true. ^self ].
	dataStream := ReadStream on: (buffer first: bytesRead)
	! !

!PWOutputStream methodsFor: 'private - finalization' stamp: 'ul 7/19/2007 23:08'!
finalize

	Smalltalk unregisterExternalObject: semaphore.


	
	
	! !

!PWOutputStream methodsFor: 'private' stamp: 'ul 7/21/2007 00:31'!
initialize

	| semaphoreIndex |
	atEnd := false.
	binary := false.
	semaphore := Semaphore new.
	dataStream := ReadStream on: (self newBuffer: 0).
	semaphoreIndex := Smalltalk registerExternalObject: semaphore.
	processWrapper perform: semaphoreSetterSelector with: semaphoreIndex.
	processWrapper class registerForFinalization: self


	
	
	! !

!PWOutputStream methodsFor: 'private' stamp: 'ul 7/19/2007 23:18'!
newBuffer: size

	^binary 
		ifTrue: [ ByteArray new: size ]
		ifFalse: [ String new: size ]! !

!PWOutputStream methodsFor: 'public' stamp: 'ul 7/20/2007 09:27'!
next

	self atEnd ifTrue: [ ^nil ].
	^dataStream next
	! !

!PWOutputStream methodsFor: 'public' stamp: 'ul 7/20/2007 09:02'!
next: anInteger

	| result index nextValue |
	result := self newBuffer: anInteger.
	index := 1.
	[ index <= anInteger and: [ (nextValue := self next) notNil ] ] whileTrue: [
		result at: index put: nextValue.
		index := index + 1 ].
	index <= anInteger ifTrue: [ ^result first: index ].
	^result
	! !

!PWOutputStream methodsFor: 'private' stamp: 'ul 7/21/2007 00:31'!
processWrapper: aProcessWrapper

	processWrapper := aProcessWrapper! !

!PWOutputStream methodsFor: 'private' stamp: 'ul 7/19/2007 23:33'!
readerSelector: aSelector

	readerSelector := aSelector! !

!PWOutputStream methodsFor: 'private' stamp: 'ul 7/19/2007 23:44'!
semaphoreSetterSelector: aSelector

	semaphoreSetterSelector := aSelector! !

!PWOutputStream methodsFor: 'public' stamp: 'ul 7/19/2007 23:22'!
upToEnd

	| result nextValue |
	result := WriteStream on: (self newBuffer: 4096).
	[ (nextValue := self next) notNil ] 
		whileTrue: [ result nextPut: nextValue ].
	^result contents
	! !

Object subclass: #ProcessWrapper
	instanceVariableNames: 'processPointer useStdout useStderr stdoutStream stderrStream'
	classVariableNames: 'Registry'
	poolDictionaries: ''
	category: 'ProcessWrapper-Core'!

!ProcessWrapper class methodsFor: 'primitive calls' stamp: 'ul 7/18/2007 22:35'!
closeStderr: anExternalProcessPointer

	<primitive: 'primitiveCloseStderr' module: 'ProcessWrapperPlugin'>
	self primitiveFailed! !

!ProcessWrapper class methodsFor: 'primitive calls' stamp: 'ul 7/18/2007 22:35'!
closeStdin: anExternalProcessPointer

	<primitive: 'primitiveCloseStdin' module: 'ProcessWrapperPlugin'>
	self primitiveFailed! !

!ProcessWrapper class methodsFor: 'primitive calls' stamp: 'ul 7/18/2007 22:35'!
closeStdout: anExternalProcessPointer

	<primitive: 'primitiveCloseStdout' module: 'ProcessWrapperPlugin'>
	self primitiveFailed! !

!ProcessWrapper class methodsFor: 'plugin handling' stamp: 'ul 7/16/2007 23:47'!
downloadPlugin

	Utilities informUserDuring: [ :bar |
		| document |
		bar value: 'Downloading plugin'.
		document := 'http://people.inf.elte.hu/uzonyile/ProcessWrapper/ProcessWrapperPlugin.dll' asUrl retrieveContents.
		bar value: 'Saving plugin'.
		(FileDirectory default fileNamed: self pluginName, '.dll')
			binary;
			nextPutAll: document content;
			close ]

! !

!ProcessWrapper class methodsFor: 'primitive calls' stamp: 'ul 7/18/2007 22:35'!
exitCode: anExternalProcessPointer

	<primitive: 'primitiveExitCode' module: 'ProcessWrapperPlugin'>
	self primitiveFailed! !

!ProcessWrapper class methodsFor: 'finalization' stamp: 'ul 7/15/2007 20:06'!
finalizationRegistry

	^Registry ifNil: [
		WeakArray isFinalizationSupported ifFalse:[ ^nil ].
		Registry := WeakRegistry new ]
! !

!ProcessWrapper class methodsFor: 'plugin handling' stamp: 'ul 7/21/2007 15:31'!
initialize

	super initialize.
	Smalltalk addToStartUpList: self.
	(FileDirectory default fileExists: self pluginName, '.dll') ifTrue: [ ^self ].
	(self confirm: 'Seems like you''re missing the plugin for ProcessWrapper. Would you like to download it now?')
		ifTrue: [ self downloadPlugin ]
		
! !

!ProcessWrapper class methodsFor: 'plugin handling' stamp: 'ul 7/15/2007 22:29'!
isPluginLoaded

	^SmalltalkImage current listLoadedModules anySatisfy: [ :each |
		each beginsWith: self pluginName ]
! !

!ProcessWrapper class methodsFor: 'primitive calls' stamp: 'ul 7/18/2007 22:35'!
isRunning: anExternalProcessPointer

	<primitive: 'primitiveIsRunning' module: 'ProcessWrapperPlugin'>
	self primitiveFailed! !

!ProcessWrapper class methodsFor: 'primitive calls' stamp: 'ul 7/18/2007 22:35'!
logLevelDebug

	<primitive: 'primitiveLogLevelDebug' module: 'ProcessWrapperPlugin'>
	self primitiveFailed! !

!ProcessWrapper class methodsFor: 'primitive calls' stamp: 'ul 7/18/2007 22:35'!
logLevelError

	<primitive: 'primitiveLogLevelError' module: 'ProcessWrapperPlugin'>
	self primitiveFailed! !

!ProcessWrapper class methodsFor: 'primitive calls' stamp: 'ul 7/18/2007 22:35'!
logLevelInfo

	<primitive: 'primitiveLogLevelInfo' module: 'ProcessWrapperPlugin'>
	self primitiveFailed! !

!ProcessWrapper class methodsFor: 'primitive calls' stamp: 'ul 7/18/2007 22:35'!
logLevelNone

	<primitive: 'primitiveLogLevelNone' module: 'ProcessWrapperPlugin'>
	self primitiveFailed! !

!ProcessWrapper class methodsFor: 'primitive calls' stamp: 'ul 7/18/2007 22:35'!
logTest

	<primitive: 'primitiveLogTest' module: 'ProcessWrapperPlugin'>
	self primitiveFailed! !

!ProcessWrapper class methodsFor: 'instance creation' stamp: 'ul 7/15/2007 13:42'!
new

	^super new
		processPointer: self newProcess;
		registerForFinalization;
		yourself.

	! !

!ProcessWrapper class methodsFor: 'primitive calls' stamp: 'ul 7/18/2007 22:35'!
newProcess

	<primitive: 'primitiveNewProcess' module: 'ProcessWrapperPlugin'>
	self primitiveFailed! !

!ProcessWrapper class methodsFor: 'plugin handling' stamp: 'ul 7/15/2007 11:36'!
pluginName
	
	^'ProcessWrapperPlugin'! !

!ProcessWrapper class methodsFor: 'startup-shutdown' stamp: 'ul 7/21/2007 14:13'!
purgeFinalizationRegistry

	self finalizationRegistry keys do: [ :each |
		self finalizationRegistry remove: each ifAbsent: [] ]
! !

!ProcessWrapper class methodsFor: 'primitive calls' stamp: 'ul 7/18/2007 22:35'!
readFromStderr: anExternalProcessPointer into: aByteArray size: anInteger

	<primitive: 'primitiveReadFromStderrIntoSize' module: 'ProcessWrapperPlugin'>
	self primitiveFailed! !

!ProcessWrapper class methodsFor: 'primitive calls' stamp: 'ul 7/18/2007 22:35'!
readFromStdout: anExternalProcessPointer into: aByteArray size: anInteger

	<primitive: 'primitiveReadFromStdoutIntoSize' module: 'ProcessWrapperPlugin'>
	self primitiveFailed! !

!ProcessWrapper class methodsFor: 'finalization' stamp: 'ul 7/15/2007 22:31'!
registerForFinalization: aProcessWrapper

	self finalizationRegistry add: aProcessWrapper 
! !

!ProcessWrapper class methodsFor: 'primitive calls' stamp: 'ul 7/18/2007 22:35'!
removeProcess: anExternalProcessPointer

	<primitive: 'primitiveRemoveProcess' module: 'ProcessWrapperPlugin'>
	self primitiveFailed! !

!ProcessWrapper class methodsFor: 'primitive calls' stamp: 'ul 7/18/2007 22:35'!
setStderrSemaphore: aSemaphoreIndex for: anExternalProcessPointer

	<primitive: 'primitiveSetStderrSemaphoreFor' module: 'ProcessWrapperPlugin'>
	self primitiveFailed! !

!ProcessWrapper class methodsFor: 'primitive calls' stamp: 'ul 7/18/2007 22:35'!
setStdoutSemaphore: aSemaphoreIndex for: anExternalProcessPointer

	<primitive: 'primitiveSetStdoutSemaphoreFor' module: 'ProcessWrapperPlugin'>
	self primitiveFailed! !

!ProcessWrapper class methodsFor: 'primitive calls' stamp: 'ul 7/18/2007 22:35'!
showWindowAtStartup: anExternalProcessPointer

	<primitive: 'primitiveShowWindowAtStartup' module: 'ProcessWrapperPlugin'>
	self primitiveFailed! !

!ProcessWrapper class methodsFor: 'primitive calls' stamp: 'ul 7/18/2007 22:35'!
startProcess: anExternalProcessPointer withCommandLine: aString

	<primitive: 'primitiveStartProcessWithCommandLine' module: 'ProcessWrapperPlugin'>
	self primitiveFailed! !

!ProcessWrapper class methodsFor: 'startup-shutdown' stamp: 'ul 7/21/2007 15:30'!
startUp: resuming

	resuming ifTrue: [ self purgeFinalizationRegistry ]! !

!ProcessWrapper class methodsFor: 'primitive calls' stamp: 'ul 7/18/2007 22:35'!
terminate: anExternalProcessPointer

	<primitive: 'primitiveTerminate' module: 'ProcessWrapperPlugin'>
	self primitiveFailed! !

!ProcessWrapper class methodsFor: 'plugin handling' stamp: 'ul 7/15/2007 22:28'!
unloadPlugin

	Smalltalk garbageCollect.
	Smalltalk garbageCollect.	"To remove the executors"
	self allInstances size isZero ifFalse: [ ^self error: 'ProcessWrapper instances hanging!!'].
	SmalltalkImage current unloadModule: self pluginName! !

!ProcessWrapper class methodsFor: 'primitive calls' stamp: 'ul 7/18/2007 22:35'!
waitForExit: anExternalProcessPointer for: timeoutMilliseconds

	<primitive: 'primitiveWaitForExitFor' module: 'ProcessWrapperPlugin'>
	self primitiveFailed! !

!ProcessWrapper class methodsFor: 'primitive calls' stamp: 'ul 7/18/2007 22:35'!
writeToStdin: anExternalProcessPointer message: aByteArray length: anInteger

	<primitive: 'primitiveWriteToStdinMessageLength' module: 'ProcessWrapperPlugin'>
	self primitiveFailed! !

!ProcessWrapper methodsFor: 'osprocess-like streaming api' stamp: 'ul 7/20/2007 18:01'!
close

	^self closeStdin! !

!ProcessWrapper methodsFor: 'input-output handling' stamp: 'ul 7/18/2007 21:04'!
closeStderr

	^self class closeStderr: processPointer ! !

!ProcessWrapper methodsFor: 'input-output handling' stamp: 'ul 7/15/2007 23:26'!
closeStdin

	^self class closeStdin: processPointer ! !

!ProcessWrapper methodsFor: 'input-output handling' stamp: 'ul 7/18/2007 21:04'!
closeStdout

	^self class closeStdout: processPointer ! !

!ProcessWrapper methodsFor: 'osprocess-like streaming api' stamp: 'ul 7/20/2007 18:04'!
errorUpToEnd

	^stderrStream upToEnd! !

!ProcessWrapper methodsFor: 'runtime information' stamp: 'ul 7/14/2007 22:04'!
exitCode

	^self class exitCode: processPointer ! !

!ProcessWrapper methodsFor: 'private - finalization' stamp: 'ul 7/21/2007 00:30'!
finalize

	self class removeProcess: processPointer
! !

!ProcessWrapper methodsFor: 'private' stamp: 'ul 7/15/2007 20:29'!
initialize

	useStdout := false.
	useStderr := false

	
! !

!ProcessWrapper methodsFor: 'runtime information' stamp: 'ul 7/14/2007 22:04'!
isRunning

	^self class isRunning: processPointer ! !

!ProcessWrapper methodsFor: 'osprocess-like streaming api' stamp: 'ul 7/20/2007 18:03'!
next

	^stdoutStream next! !

!ProcessWrapper methodsFor: 'osprocess-like streaming api' stamp: 'ul 7/20/2007 18:03'!
next: anInteger

	^stdoutStream next: anInteger! !

!ProcessWrapper methodsFor: 'osprocess-like streaming api' stamp: 'ul 7/30/2007 17:02'!
nextPut: aCharacterOrByte

	^self nextPutAll: 
		(aCharacterOrByte isCharacter
			ifTrue: [ String with: aCharacterOrByte ]
			ifFalse: [ ByteArray with: aCharacterOrByte ])! !

!ProcessWrapper methodsFor: 'osprocess-like streaming api' stamp: 'ul 7/20/2007 17:34'!
nextPutAll: aStringOrByteArray

	^self writeToStdin: aStringOrByteArray asByteArray! !

!ProcessWrapper methodsFor: 'private' stamp: 'ul 7/19/2007 23:47'!
prepareStderr

	useStderr ifFalse: [ ^self ].
	stderrStream := PWOutputStream on: self with: #readFromStderrInto: with: #setStderrSemaphore:
! !

!ProcessWrapper methodsFor: 'private' stamp: 'ul 7/19/2007 23:46'!
prepareStdout

	useStdout ifFalse: [ ^self ].
	stdoutStream := PWOutputStream on: self with: #readFromStdoutInto: with: #setStdoutSemaphore:
! !

!ProcessWrapper methodsFor: 'private' stamp: 'ul 7/14/2007 21:54'!
processPointer: aSmallInteger

	processPointer ifNil: [ processPointer := aSmallInteger ]! !

!ProcessWrapper methodsFor: 'private' stamp: 'ul 7/19/2007 23:31'!
readFromStderrInto: aByteArrayOrString

	^self class 
		readFromStderr: processPointer 
		into: aByteArrayOrString 
		size: aByteArrayOrString size! !

!ProcessWrapper methodsFor: 'private' stamp: 'ul 7/19/2007 23:31'!
readFromStdoutInto: aByteArrayOrString

	^self class 
		readFromStdout: processPointer 
		into: aByteArrayOrString 
		size: aByteArrayOrString size! !

!ProcessWrapper methodsFor: 'private - finalization' stamp: 'ul 7/15/2007 22:32'!
registerForFinalization
	
	self class registerForFinalization: self! !

!ProcessWrapper methodsFor: 'private' stamp: 'ul 7/19/2007 23:45'!
setStderrSemaphore: aSemaphoreIndex

	^self class 
		setStderrSemaphore: aSemaphoreIndex  
		for: processPointer ! !

!ProcessWrapper methodsFor: 'private' stamp: 'ul 7/19/2007 23:45'!
setStdoutSemaphore: aSemaphoreIndex

	^self class 
		setStdoutSemaphore: aSemaphoreIndex  
		for: processPointer ! !

!ProcessWrapper methodsFor: 'pre-start options' stamp: 'ul 7/14/2007 23:28'!
showWindowAtStartup

	^self class showWindowAtStartup: processPointer ! !

!ProcessWrapper methodsFor: 'start-stop' stamp: 'ul 7/21/2007 00:27'!
startWithCommand: aStringOrByteArray
	
	| input |
	self 
		prepareStdout;
		prepareStderr.
	input := aStringOrByteArray asByteArray.
	input last = 0 ifFalse: [ input := input copyWith: 0 ].
	^self class startProcess: processPointer  withCommandLine: input! !

!ProcessWrapper methodsFor: 'start-stop' stamp: 'ul 7/15/2007 22:19'!
startWithShellCommand: aStringOrByteArray

	^self startWithCommand: 'cmd.exe /C ' asByteArray, aStringOrByteArray asByteArray! !

!ProcessWrapper methodsFor: 'input-output handling' stamp: 'ul 7/19/2007 23:50'!
stderrStream

	^stderrStream 

	! !

!ProcessWrapper methodsFor: 'input-output handling' stamp: 'ul 7/19/2007 23:50'!
stdoutStream

	^stdoutStream 

	! !

!ProcessWrapper methodsFor: 'start-stop' stamp: 'ul 7/14/2007 23:29'!
terminate

	^self class terminate: processPointer ! !

!ProcessWrapper methodsFor: 'osprocess-like streaming api' stamp: 'ul 7/20/2007 18:03'!
upToEnd

	^stdoutStream upToEnd! !

!ProcessWrapper methodsFor: 'pre-start options' stamp: 'ul 7/15/2007 20:29'!
useStderr

	useStderr := true! !

!ProcessWrapper methodsFor: 'pre-start options' stamp: 'ul 7/15/2007 20:29'!
useStdout

	useStdout := true! !

!ProcessWrapper methodsFor: 'start-stop' stamp: 'ul 7/15/2007 00:00'!
waitForExitFor: timeoutMilliseconds

	^self class waitForExit: processPointer for: timeoutMilliseconds ! !

!ProcessWrapper methodsFor: 'input-output handling' stamp: 'ul 7/14/2007 23:33'!
writeToStdin: aByteArray

	^self class writeToStdin:  processPointer message:  aByteArray length: aByteArray size! !

TestCase subclass: #ProcessWrapperClassTests
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ProcessWrapper-Core-Tests'!

!ProcessWrapperClassTests methodsFor: 'as yet unclassified' stamp: 'ul 7/16/2007 13:08'!
testPluginLoading
	"Fails with an error if there are references to ProcessWrapper instances."

	ProcessWrapper unloadPlugin.
	self shouldnt: (ProcessWrapper isPluginLoaded).
	ProcessWrapper new.
	self should: (ProcessWrapper isPluginLoaded).! !

TestCase subclass: #ProcessWrapperTests
	instanceVariableNames: 'process fileNames'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ProcessWrapper-Core-Tests'!

ProcessWrapperTests subclass: #ProcessWrapperCommandShellTests
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ProcessWrapper-Core-Tests'!

!ProcessWrapperCommandShellTests methodsFor: 'as yet unclassified' stamp: 'ul 7/30/2007 16:55'!
testCopy

	| file1 file2 |
	file1 := self newFileName.
	file2 := self newFileName.
	(FileDirectory default fileNamed: file1) close.
	self should: (process startWithShellCommand: 'copy ', file1, ' ', file2).
	self should: (process waitForExitFor: 5000).
	self shouldnt: process isRunning.
	self should: process exitCode isZero.
	self should: (FileDirectory default fileExists: file1).
	self should: (FileDirectory default fileExists: file2).
! !

!ProcessWrapperCommandShellTests methodsFor: 'as yet unclassified' stamp: 'ul 7/30/2007 16:55'!
testDelete

	| file |
	file := self newFileName.
	(FileDirectory default fileNamed: file) close.
	self should: (process startWithShellCommand: 'del ', file).
	self should: (process waitForExitFor: 5000).
	self shouldnt: process isRunning.
	self should: process exitCode isZero.
	self shouldnt: (FileDirectory default fileExists: file).
! !

!ProcessWrapperCommandShellTests methodsFor: 'as yet unclassified' stamp: 'ul 7/30/2007 16:55'!
testEcho

	process useStdout.
	self should: (process startWithShellCommand: 'echo blabla').
	self should: (process upToEnd = ('blabla', String crlf)).
	self shouldnt: process isRunning.
	self should: process exitCode isZero.
	! !

!ProcessWrapperCommandShellTests methodsFor: 'as yet unclassified' stamp: 'ul 7/30/2007 16:54'!
testMove

	| file1 file2 |
	file1 := self newFileName.
	file2 := self newFileName.
	(FileDirectory default fileNamed: file1) close.	
	process startWithShellCommand: 'move ', file1, ' ', file2.
	process waitForExitFor: 1000.
	self shouldnt: process isRunning.
	self should: process exitCode isZero.
	self shouldnt: (FileDirectory default fileExists: file1).
	self should: (FileDirectory default fileExists: file2).
! !

!ProcessWrapperCommandShellTests methodsFor: 'as yet unclassified' stamp: 'ul 7/30/2007 16:56'!
testType

	| file |
	file := self newFileName.
	(FileDirectory default fileNamed: file)
		nextPutAll: 'blabla';
		close.
	process useStdout.
	self should: (process startWithShellCommand: 'type ', file).
	self should: (process waitForExitFor: 5000).
	self shouldnt: process isRunning.
	self should: process exitCode isZero.
	self should: (process upToEnd = 'blabla').
! !

ProcessWrapperTests subclass: #ProcessWrapperOpeningWindowTests
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ProcessWrapper-Core-Tests'!

!ProcessWrapperOpeningWindowTests methodsFor: 'as yet unclassified' stamp: 'ul 7/30/2007 16:57'!
testExplorer
	"open an explorer window to the default directory"

	self should: process showWindowAtStartup.
	self should: (process startWithCommand: 'explorer .').
	self should: (process waitForExitFor: 5000).
	self shouldnt: process isRunning.
	self should: process exitCode isZero.
	! !

!ProcessWrapperTests methodsFor: 'as yet unclassified' stamp: 'ul 7/30/2007 17:03'!
newFileName

	| fileName |
	fileName := 'testFile', UUID new asString36, '.txt'.
	fileNames add: fileName.
	^fileName! !

!ProcessWrapperTests methodsFor: 'as yet unclassified' stamp: 'ul 7/30/2007 16:16'!
setUp

	process := ProcessWrapper new.
	fileNames := Set new! !

!ProcessWrapperTests methodsFor: 'as yet unclassified' stamp: 'ul 7/30/2007 16:17'!
tearDown

	process isRunning ifTrue: [
		process terminate ].
	process := nil. "Release the ProcessWrappers for successful plugin unloading"
	fileNames do: [ :each |
		FileDirectory default deleteFileNamed: each]
	! !

ProcessWrapperTests subclass: #ProcessWrapperUnixUtilsTests
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ProcessWrapper-Core-Tests'!

!ProcessWrapperUnixUtilsTests commentStamp: 'ul 7/20/2007 21:13' prior: 0!
To run these tests you'll need the unixutils suit from: http://unxutils.sourceforge.net/
The exe files (cat.exe touch.exe) have to be on the path of the vm's process.!

!ProcessWrapperUnixUtilsTests methodsFor: 'as yet unclassified' stamp: 'ul 7/30/2007 16:59'!
testCat

	process useStdout.
	self should: (process startWithCommand: 'cat').
	self should: (process isRunning).
	self shouldnt: (process waitForExitFor: 5000).
	self should: (process writeToStdin: 'bla').
	self should: process isRunning.
	self should: ((process next: 3) = 'bla').
	self should: (process closeStdin).
	self should: (process waitForExitFor: 5000).
	self shouldnt: process isRunning.
	self should: process exitCode isZero.
	! !

!ProcessWrapperUnixUtilsTests methodsFor: 'as yet unclassified' stamp: 'ul 7/30/2007 16:59'!
testTouch

	| file |
	file := self newFileName.
	self should: (process startWithCommand: 'touch ', file).
	self should: (process waitForExitFor: 5000).
	self shouldnt: process isRunning.
	self should: process exitCode isZero.
	self should: (FileDirectory default fileExists: file).
	! !
ProcessWrapper initialize!
